pub struct ElectionBounds {
pub voters: DataProviderBounds,
pub targets: DataProviderBounds,
}Expand description
The voter and target bounds of an election.
The bounds are defined over two axis: count of element of the election (voters or targets) and
the size of the SCALE encoded result snapshot.
Fields
voters: DataProviderBoundstargets: DataProviderBoundsImplementations
Sourceimpl ElectionBounds
impl ElectionBounds
Sourcepub fn ensure_voters_limits(
self,
count: CountBound,
size: SizeBound,
) -> Result<(), &'static str>
pub fn ensure_voters_limits( self, count: CountBound, size: SizeBound, ) -> Result<(), &'static str>
Returns an error if the provided count and size do not fit in the voter’s election
bounds.
Sourcepub fn ensure_targets_limits(
self,
count: CountBound,
size: SizeBound,
) -> Result<(), &'static str>
pub fn ensure_targets_limits( self, count: CountBound, size: SizeBound, ) -> Result<(), &'static str>
Returns an error if the provided count and size do not fit in the target’s election
bounds.