pub struct SizeBound(pub u32);Expand description
Size type for data provider bounds.
Encapsulates the size limit of things that can be bounded in an election, such as voters, targets or anything else. The size unit can represent anything depending on the election logic and implementation, but it most likely will represent bytes in SCALE encoding in this context.
This struct is defined mostly to prevent callers from mistakenly using CountBound instead of
SizeBound and vice-versa.
Tuple Fields
0: u32Trait Implementations
Sourceimpl Ord for SizeBound
impl Ord for SizeBound
Sourceimpl PartialOrd for SizeBound
impl PartialOrd for SizeBound
impl Copy for SizeBound
impl Eq for SizeBound
impl StructuralPartialEq for SizeBound